define(
//begin v1.x content
{
	"HKD_displayName": "Hongkong-Dollar",
	"CHF_displayName": "Schweizer Franken",
	"JPY_symbol": "¥",
	"CAD_displayName": "Kanadischer Dollar",
	"HKD_symbol": "HK$",
	"CNY_displayName": "Renminbi Yuan",
	"USD_symbol": "$",
	"AUD_displayName": "Australischer Dollar",
	"JPY_displayName": "Japanische Yen",
	"CAD_symbol": "CA$",
	"USD_displayName": "US-Dollar",
	"EUR_symbol": "€",
	"CNY_symbol": "CN¥",
	"GBP_displayName": "Britisches Pfund Sterling",
	"GBP_symbol": "£",
	"AUD_symbol": "AU$",
	"EUR_displayName": "Euro"
}
//end v1.x content
);